@@ -1,5 +1,5 @@
 /* GAdmin-OpenVPN - An easy to use GTK+ frontend for the openvpn client.
- * Copyright (C) 2008 - 2009 Magnus Loef <magnus-swe@telia.com> 
+ * Copyright (C) 2008 - 2010 Magnus Loef <magnus-swe@telia.com> 
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -21,12 +21,12 @@
 #ifndef commands_H
 #	define commands_H
 
-int run_command(gchar *command);
+int  run_command(gchar *command);
 void run_command_show_err(gchar *command);
-int file_exists(char *infile);
+int  file_exists(char *infile);
+int  networkmanager_start();
+void networkmanager_stop();
 void init_start(struct w *widgets);
 void init_stop(struct w *widgets);
 
-int using_tls(void);
-
 #endif
